Last REST Error
lastRestError.RdReturns details about the last failed REST call, or NULL if the last call succeeded. Since improveR is single-threaded, this is safe to use after any REST operation.

lastRestError.RdReturns details about the last failed REST call, or NULL if the last call succeeded. Since improveR is single-threaded, this is safe to use after any REST operation.