Skip to contents

Retrieves all registered tool categories from the improve repository.

Usage

loadToolCategories()

Value

A data frame of tool categories with columns such as id, name, identifier. Returns NULL if no categories exist.

References

ics1229