Skip to contents

Binds a file as the command-file process variable on an already-realised step. This is used when a step has been created and realised, but the command file needs to be set or changed after the fact.

Usage

setCommandFile(stepIdent, fileIdent, from = pwd())

Arguments

stepIdent

Identifier of the step. Can be a path, resource ID, entity ID, or a data frame row from loadResource().

fileIdent

Identifier of the file to bind as command file. Can be a path, resource ID, entity ID, or a data frame row from loadResource().

from

Base path for resolving relative paths. Defaults to pwd().

Value

The updated process variables data frame, invisibly. Returns NULL on failure.

References

ccs40

Examples

if (FALSE) { # \dontrun{
setCommandFile("/Projects/MyTree/Step 1", "/Projects/Files/myScript.R")
} # }