Skip to contents

Unloads All Reviews

Usage

unloadReviews()

Value

No meaningful value - called for its side effect of dropping the list of all reviews from the cache. Note that the list is loaded once before it is dropped, so the call does reach the server.

References

ics348