Skip to contents

Updates the command of an existing tool instance on a runserver.

Usage

updateToolInstance(runserverId, instanceId, command)

Arguments

runserverId

Character. The ID of the runserver.

instanceId

Character. The ID of the tool instance.

command

Character. The new command string.

Value

A list with the updated instance details, or NULL on failure.

References

ccs37