Clear Connection Data
clearConnectionData.Rddeletes repoUrl, stepId, and token from the environment variables and calls improveDisconnect
Value
No meaningful value - called for its side effects on the environment
variables, the CLI user profile and the connection. The value passed through from
improveDisconnect() is an implementation detail and must not be relied on.