Creates a New Review
createReview.RdCreates a review resource under the specified parent folder, containing the given resources and assigned to the given reviewers.
Usage
createReview(
name,
parentIdent,
comment,
templateId,
resourceIds,
reviewerIds,
dueDate,
from = pwd()
)Arguments
- name
Character. Name of the review.
- parentIdent
Identifier of the parent folder. Can be a path, resource ID, entity ID, or a data frame row from
loadResource().- comment
Character. Review comment.
- templateId
Character. ID (UUID) of the review template.
- resourceIds
Character vector of resource IDs (UUIDs) to include in the review.
- reviewerIds
Character vector of reviewer user IDs (UUIDs).
- dueDate
Character. Due date in
yyyy-mm-ddformat.- from
Base path for resolving relative paths. Defaults to
pwd().