loadToolCategories.Rd
Retrieves all registered tool categories from the improve repository.
loadToolCategories()
A data frame of tool categories with columns such as id, name, identifier. Returns NULL if no categories exist.
NULL
ics1229
createToolCategory, loadToolsForCategory
createToolCategory
loadToolsForCategory