loadToolsForCategory.Rd
Retrieves all tools registered under a specific tool category.
loadToolsForCategory(categoryId)
Character. The ID of the tool category.
A data frame of tools with columns such as id, name, categoryId. Returns NULL if no tools exist in the category.
NULL
ics1230
loadToolCategories, createTool
loadToolCategories
createTool