unloadResource.Rd
Unloads a resource.
unloadResource(ident, from = pwd())
id
pwd for relative path
No meaningful value - called for its side effect of dropping the resource from the cache; a version is dropped from the version cache, everything else from the resource cache. Does nothing when ident resolves to no resource.
ident
ics1090