Update File Content Prerequisite: must be a file. Multiple files can be updated at once.
updateFileContent.RdUpdate File Content Prerequisite: must be a file. Multiple files can be updated at once.
Value
The refreshed resource after the upload, as refreshResource() returns it.
NULL when ident resolves to no resource or the upload itself failed. For several
idents the refreshed resources of all of them, merged.