Update a Tool Parameter Value
updateToolParameter.RdUpdates the value of an existing parameter on a tool instance.
Arguments
- runserverId
Character. The ID of the runserver.
- instanceId
Character. The ID of the tool instance.
- parameterId
Character. The ID of the parameter to update.
- value
Character. The new parameter value.
- parameterLovId
Character or NULL. The parameter LOV ID. If NULL, the existing parameter is fetched to determine it.